searchNodes=[{"doc":"This module provides functions for serializing and deserializing Elixir terms using the MessagePack format. Data conversion The following table shows how Elixir types are serialized to MessagePack types and how MessagePack types are deserialized back to Elixir types. Elixir MessagePack Elixir nil nil nil true boolean true false boolean false -1 integer -1 1.25 float 1.25 N/A ¹ NaN Msgpax.NaN ² N/A ¹ +infinity Msgpax.Infinity ² N/A ¹ -infinity Msgpax.NegInfinity ² :ok string &quot;ok&quot; Atom string &quot;Elixir.Atom&quot; &quot;text&quot; string &quot;text&quot; &quot;\\xFF\\xFF&quot; string &quot;\\xFF\\xFF&quot; #Msgpax.Bin&lt;&quot;\\xFF&quot;&gt; binary &quot;\\xFF&quot; ³ %{foo: &quot;bar&quot;} map %{&quot;foo&quot; =&gt; &quot;bar&quot;} [foo: &quot;bar&quot;] map %{&quot;foo&quot; =&gt; &quot;bar&quot;} [1, true] array [1, true] #Msgpax.Ext&lt;4, &quot;02:12&quot;&gt; extension #Msgpax.Ext&lt;4, &quot;02:12&quot;&gt; #DateTime&lt;2017-12-06 00:00:00Z&gt; extension #DateTime&lt;2017-12-06 00:00:00Z&gt; ¹ Msgpax.Packer provides helper functions to facilitate the serialization of natively unsupported data types. ² NaN and ±infinity are not enabled by default. See unpack/2 for for more information. ³ To deserialize back to Msgpax.Bin structs see the unpack/2 options.","ref":"Msgpax.html","title":"Msgpax","type":"module"},{"doc":"Serializes the given term . This function returns iodata by default; if you want to force the result to be a binary, you can use IO.iodata_to_binary/1 or use the :iodata option (see the &quot;Options&quot; section below). This function returns {:ok, iodata} if the serialization is successful, {:error, exception} otherwise, where exception is a Msgpax.PackError struct which can be raised or converted to a more human-friendly error message with Exception.message/1 . See Msgpax.PackError for all the possible reasons for a packing error. Options :iodata - (boolean) if true , this function returns the encoded term as iodata, if false as a binary. Defaults to true . Examples iex&gt; { :ok , packed } = Msgpax . pack ( &quot;foo&quot; ) iex&gt; IO . iodata_to_binary ( packed ) &lt;&lt; 163 , 102 , 111 , 111 &gt;&gt; iex&gt; Msgpax . pack ( 20000000000000000000 ) { :error , % Msgpax.PackError { reason : { :too_big , 20000000000000000000 } } } iex&gt; Msgpax . pack ( &quot;foo&quot; , iodata : false ) { :ok , &lt;&lt; 163 , 102 , 111 , 111 &gt;&gt; }","ref":"Msgpax.html#pack/2","title":"Msgpax.pack/2","type":"function"},{"doc":"Works as pack/1 , but raises if there's an error. This function works like pack/1 , except it returns the term (instead of {:ok, term} ) if the serialization is successful or raises a Msgpax.PackError exception otherwise. Options This function accepts the same options as pack/2 . Examples iex&gt; &quot;foo&quot; |&gt; Msgpax . pack! ( ) |&gt; IO . iodata_to_binary ( ) &lt;&lt; 163 , 102 , 111 , 111 &gt;&gt; iex&gt; Msgpax . pack! ( 20000000000000000000 ) ** (Msgpax.PackError) too big value: 20000000000000000000 iex&gt; Msgpax . pack! ( &quot;foo&quot; , iodata : false ) &lt;&lt; 163 , 102 , 111 , 111 &gt;&gt;","ref":"Msgpax.html#pack!/2","title":"Msgpax.pack!/2","type":"function"},{"doc":"Serializes term and turns the result into a Msgpax.Fragment . This function returns {:ok, fragment} if the serialization is successful, {:error, exception} otherwise, where exception is a Msgpax.PackError struct which can be raised or converted to a more human-friendly error message with Exception.message/1 . See Msgpax.PackError for all the possible reasons for a packing error. This is useful for optimization, for instance, to avoid packing heavy terms repetitively. Another good use case for fragments would be data encapsulation. For example, if we want to &quot;interpolate&quot; some MessagePack data into the payload without having to unpack and pack them. Options This function accepts the same options as pack/2 . Examples iex&gt; { :ok , fragment } = Msgpax . pack_fragment ( &quot;HUGE&quot; ) iex&gt; { :ok , packed } = Msgpax . pack ( [ fragment , fragment ] ) iex&gt; IO . iodata_to_binary ( packed ) &lt;&lt; 146 , 164 , 72 , 85 , 71 , 69 , 164 , 72 , 85 , 71 , 69 &gt;&gt;","ref":"Msgpax.html#pack_fragment/2","title":"Msgpax.pack_fragment/2","type":"function"},{"doc":"Works as pack_fragment/2 , but raises if there's an error. This function works like pack_fragment!/2 , except it returns the fragment (instead of {:ok, fragment} ) if the serialization is successful or raises a Msgpax.PackError exception otherwise. Options This function accepts the same options as pack_fragment/2 . Examples iex&gt; fragment = Msgpax . pack_fragment! ( &quot;HUGE&quot; ) iex&gt; { :ok , packed } = Msgpax . pack ( [ fragment , fragment ] ) iex&gt; IO . iodata_to_binary ( packed ) &lt;&lt; 146 , 164 , 72 , 85 , 71 , 69 , 164 , 72 , 85 , 71 , 69 &gt;&gt;","ref":"Msgpax.html#pack_fragment!/2","title":"Msgpax.pack_fragment!/2","type":"function"},{"doc":"Deserializes the given iodata . This function deserializes the given iodata into an Elixir term. It returns {:ok, term} if the deserialization is successful, {:error, exception} otherwise, where exception is a Msgpax.UnpackError struct which can be raised or converted to a more human-friendly error message with Exception.message/1 . See Msgpax.UnpackError for all the possible reasons for an unpacking error. Options :binary - (boolean) if true , then binaries are decoded as Msgpax.Bin structs instead of plain Elixir binaries. Defaults to false . :ext - (module) a module that implements the Msgpax.Ext.Unpacker behaviour. For more information, see the docs for Msgpax.Ext.Unpacker . :nonfinite_floats - (boolean) if true , deserializes NaN and ±infinity to &quot;signalling&quot; atoms (see the &quot;Data conversion&quot; section), otherwise errors. Defaults to false . Examples iex&gt; Msgpax . unpack ( &lt;&lt; 163 , &quot;foo&quot; &gt;&gt; ) { :ok , &quot;foo&quot; } iex&gt; Msgpax . unpack ( &lt;&lt; 163 , &quot;foo&quot; , &quot;junk&quot; &gt;&gt; ) { :error , % Msgpax.UnpackError { reason : { :excess_bytes , &quot;junk&quot; } } } iex&gt; packed = Msgpax . pack! ( Msgpax.Bin . new ( &lt;&lt; 3 , 18 , 122 , 27 , 115 &gt;&gt; ) ) iex&gt; { :ok , bin } = Msgpax . unpack ( packed , binary : true ) iex&gt; bin # Msgpax.Bin &lt; &lt;&lt; 3 , 18 , 122 , 27 , 115 &gt;&gt; &gt;","ref":"Msgpax.html#unpack/2","title":"Msgpax.unpack/2","type":"function"},{"doc":"Works like unpack/2 , but raises in case of errors. This function works like unpack/2 , but it returns term (instead of {:ok, term} ) if deserialization is successful, otherwise raises a Msgpax.UnpackError exception. Example iex&gt; Msgpax . unpack! ( &lt;&lt; 163 , &quot;foo&quot; &gt;&gt; ) &quot;foo&quot; iex&gt; Msgpax . unpack! ( &lt;&lt; 163 , &quot;foo&quot; , &quot;junk&quot; &gt;&gt; ) ** (Msgpax.UnpackError) found excess bytes: &quot;junk&quot; iex&gt; packed = Msgpax . pack! ( Msgpax.Bin . new ( &lt;&lt; 3 , 18 , 122 , 27 , 115 &gt;&gt; ) ) iex&gt; Msgpax . unpack! ( packed , binary : true ) # Msgpax.Bin &lt; &lt;&lt; 3 , 18 , 122 , 27 , 115 &gt;&gt; &gt;","ref":"Msgpax.html#unpack!/2","title":"Msgpax.unpack!/2","type":"function"},{"doc":"Deserializes part of the given iodata . This function works like unpack/2 , but instead of requiring the input to be a MessagePack-serialized term with nothing after that, it accepts leftover bytes at the end of iodata and only deserializes the part of the input that makes sense. It returns {:ok, term, rest} if deserialization is successful, {:error, exception} otherwise (where exception is a Msgpax.UnpackError struct). See unpack/2 for more information on the supported options. Examples iex&gt; Msgpax . unpack_slice ( &lt;&lt; 163 , &quot;foo&quot; , &quot;junk&quot; &gt;&gt; ) { :ok , &quot;foo&quot; , &quot;junk&quot; } iex&gt; Msgpax . unpack_slice ( &lt;&lt; 163 , &quot;fo&quot; &gt;&gt; ) { :error , % Msgpax.UnpackError { reason : { :invalid_format , 163 } } }","ref":"Msgpax.html#unpack_slice/2","title":"Msgpax.unpack_slice/2","type":"function"},{"doc":"Works like unpack_slice/2 but raises in case of error. This function works like unpack_slice/2 , but returns just {term, rest} if deserialization is successful and raises a Msgpax.UnpackError exception if it's not. Examples iex&gt; Msgpax . unpack_slice! ( &lt;&lt; 163 , &quot;foo&quot; , &quot;junk&quot; &gt;&gt; ) { &quot;foo&quot; , &quot;junk&quot; } iex&gt; Msgpax . unpack_slice! ( &lt;&lt; 163 , &quot;fo&quot; &gt;&gt; ) ** (Msgpax.UnpackError) invalid format, first byte: 163","ref":"Msgpax.html#unpack_slice!/2","title":"Msgpax.unpack_slice!/2","type":"function"},{"doc":"A struct to represent the MessagePack Binary type . Elixir binaries are serialized and deserialized as MessagePack strings : Msgpax.Bin is used when you want to enforce the serialization of a binary into the Binary MessagePack type. Deserialization functions (such as Msgpax.unpack/2 ) provide an option to deserialize Binary terms (which are deserialized to Elixir binaries by default) to Msgpax.Bin structs.","ref":"Msgpax.Bin.html","title":"Msgpax.Bin","type":"module"},{"doc":"Creates a new Msgpax.Bin struct from the given binary. Examples iex&gt; Msgpax.Bin . new ( &quot;foo&quot; ) # Msgpax.Bin &lt; &quot;foo&quot; &gt;","ref":"Msgpax.Bin.html#new/1","title":"Msgpax.Bin.new/1","type":"function"},{"doc":"","ref":"Msgpax.Bin.html#t:t/0","title":"Msgpax.Bin.t/0","type":"type"},{"doc":"A struct used to represent the MessagePack Extension type . Examples Let's say we want to be able to serialize a custom type that consists of a byte data repeated count times. We could represent this as a RepByte struct in Elixir: defmodule RepByte do defstruct [ :data , :count ] end A simple (albeit not space efficient) approach to encoding such data is simply a binary containing data for count times: %RepByte{data: ?a, count: 2} would be encoded as &quot;aa&quot; . We can now define the Msgpax.Packer protocol for the RepByte struct to tell Msgpax how to encode this struct (we'll choose 10 as an arbitrary integer to identify the type of this extension). defimpl Msgpax.Packer , for : RepByte do @rep_byte_ext_type 10 def pack ( % RepByte { data : byte , count : count } ) do @rep_byte_ext_type |&gt; Msgpax.Ext . new ( String . duplicate ( &lt;&lt; byte &gt;&gt; , count ) ) |&gt; Msgpax.Packer . pack ( ) end end Now, we can pack RepByte s: iex&gt; packed = Msgpax . pack! ( % RepByte { data : ?a , count : 3 } ) iex&gt; Msgpax . unpack! ( packed ) # Msgpax.Ext &lt; 10 , &quot;aaa&quot; &gt; Unpacking As seen in the example above, since the RepByte struct is packed as a MessagePack extension, it will be unpacked as that extension later on; what we may want, however, is to unpack that extension back to a RepByte struct. To do this, we can pass an :ext option to Msgpax.unpack/2 (and other unpacking functions). This option has to be a module that implements the Msgpax.Ext.Unpacker behaviour; it will be used to unpack extensions to arbitrary Elixir terms. For our RepByte example, we could create an unpacker module like this: defmodule MyExtUnpacker do @behaviour Msgpax.Ext.Unpacker @rep_byte_ext_type 10 @impl true def unpack ( % Msgpax.Ext { type : @rep_byte_ext_type , data : data } ) do &lt;&lt; byte , _rest :: binary &gt;&gt; = data { :ok , % RepByte { data : byte , count : byte_size ( data ) } } end end With this in place, we can now unpack a packed RepByte back to a RepByte struct: iex&gt; packed = Msgpax . pack! ( % RepByte { data : ?a , count : 3 } ) iex&gt; Msgpax . unpack! ( packed , ext : MyExtUnpacker ) % RepByte { data : ?a , count : 3 }","ref":"Msgpax.Ext.html","title":"Msgpax.Ext","type":"module"},{"doc":"Creates a new Msgpax.Ext struct. type must be an integer in 0..127 and it will be used as the type of the extension (whose meaning depends on your application). data must be an iodata containing the serialized extension (whose serialization depends on your application). Examples iex&gt; Msgpax.Ext . new ( 24 , &quot;foo&quot; ) # Msgpax.Ext &lt; 24 , &quot;foo&quot; &gt; iex&gt; Msgpax.Ext . new ( 25 , &#39;bar&#39; ) # Msgpax.Ext &lt; 25 , &#39;bar&#39; &gt;","ref":"Msgpax.Ext.html#new/2","title":"Msgpax.Ext.new/2","type":"function"},{"doc":"","ref":"Msgpax.Ext.html#t:t/0","title":"Msgpax.Ext.t/0","type":"type"},{"doc":"","ref":"Msgpax.Ext.html#t:type/0","title":"Msgpax.Ext.type/0","type":"type"},{"doc":"Behaviour to unpack Msgpax.Ext structs into arbitrary terms. Modules that implement this behaviour can be passed as the value of the :ext option in Msgpax.unpack/2 and Msgpax.unpack_slice/2 (and their bang! variants). See the documentation for Msgpax.Ext for usage examples.","ref":"Msgpax.Ext.Unpacker.html","title":"Msgpax.Ext.Unpacker","type":"behaviour"},{"doc":"Invoked when unpacking the given extension. It should return {:ok, value} to have Msgpax return value when unpacking the given extension, or :error if there's an error while unpacking.","ref":"Msgpax.Ext.Unpacker.html#c:unpack/1","title":"Msgpax.Ext.Unpacker.unpack/1","type":"callback"},{"doc":"Represents a fragment of MessagePack data.","ref":"Msgpax.Fragment.html","title":"Msgpax.Fragment","type":"module"},{"doc":"Builds a Msgpax.Fragment from the given packed_data . Examples iex&gt; Msgpax.Fragment . new ( &lt;&lt; 192 &gt;&gt; ) # Msgpax.Fragment &lt; &lt;&lt; 192 &gt;&gt; &gt;","ref":"Msgpax.Fragment.html#new/1","title":"Msgpax.Fragment.new/1","type":"function"},{"doc":"","ref":"Msgpax.Fragment.html#t:t/0","title":"Msgpax.Fragment.t/0","type":"opaque"},{"doc":"The Msgpax.Packer protocol is responsible for serializing any Elixir data structure according to the MessagePack specification. Some notable properties of the implementation of this protocol for the built-in Elixir data structures: atoms are encoded as strings (i.e., they're converted to strings first and then encoded as strings) bitstrings can only be encoded as long as they're binaries (and not actual bitstrings - i.e., the number of bits must be a multiple of 8) binaries (or Msgpax.Bin structs) containing 2^32 or more bytes cannot be encoded maps with more than (2^32) - 1 elements cannot be encoded lists with more than (2^32) - 1 elements cannot be encoded integers larger than (2^64) - 1 or smaller than -2^63 cannot be encoded Serializing a subset of fields for structs The Msgpax.Packer protocol supports serialization of only a subset of the fields of a struct when derived. For example: defmodule User do @derive [ { Msgpax.Packer , fields : [ :name ] } ] defstruct [ :name , :sensitive_data ] end In the example, packing User will only serialize the :name field and leave out the :sensitive_data field. By default, the :__struct__ field is taken out of the struct before packing it. If you want this field to be present in the packed map, you have to set the :include_struct_field option to true . Unpacking back to Elixir structs When packing a struct, that struct will be packed as the underlying map and will be unpacked with string keys instead of atom keys. This makes it hard to reconstruct the map as tools like Kernel.struct/2 can't be used (given keys are strings). Also, unless specifically stated with the :include_struct_field option, the :__struct__ field is lost when packing a struct, so information about which struct it was is lost. % User { name : &quot;Juri&quot; } |&gt; Msgpax . pack! ( ) |&gt; Msgpax . unpack! ( ) #=&gt; %{&quot;name&quot; =&gt; &quot;Juri&quot;} These things can be overcome by using something like Maptu , which helps to reconstruct structs: map = % User { name : &quot;Juri&quot; } |&gt; Msgpax . pack! ( ) |&gt; Msgpax . unpack! ( ) Maptu . struct! ( User , map ) #=&gt; %User{name: &quot;Juri&quot;} map = %{ &quot;__struct__&quot; =&gt; &quot;Elixir.User&quot; , &quot;name&quot; =&gt; &quot;Juri&quot; } |&gt; Msgpax . pack! ( ) |&gt; Msgpax . unpack! ( ) Maptu . struct! ( map ) #=&gt; %User{name: &quot;Juri&quot;}","ref":"Msgpax.Packer.html","title":"Msgpax.Packer","type":"protocol"},{"doc":"This function serializes term . It returns an iodata result.","ref":"Msgpax.Packer.html#pack/1","title":"Msgpax.Packer.pack/1","type":"function"},{"doc":"Returns serialized infinity in 64-bit format.","ref":"Msgpax.Packer.html#pack_infinity/1","title":"Msgpax.Packer.pack_infinity/1","type":"function"},{"doc":"Returns serialized NaN in 64-bit format.","ref":"Msgpax.Packer.html#pack_nan/0","title":"Msgpax.Packer.pack_nan/0","type":"function"},{"doc":"","ref":"Msgpax.Packer.html#t:t/0","title":"Msgpax.Packer.t/0","type":"type"},{"doc":"A Plug.Parsers plug for parsing a MessagePack-encoded body. Look at the documentation for Plug.Parsers for more information on how to use Plug.Parsers . This parser accepts the :unpacker option to configure how unpacking should be done. Its value can either be a module that implements the unpack!/1 function or a module, function, and arguments tuple. Note, the response body will be prepended to the given list of arguments before applying. Examples defmodule MyPlugPipeline do use Plug.Builder plug Plug.Parsers , parsers : [ Msgpax.PlugParser ] , pass : [ &quot;application/msgpack&quot; ] # Or use the :unpacker option: plug Plug.Parsers , parsers : [ Msgpax.PlugParser ] , pass : [ &quot;application/msgpack&quot; ] , unpacker : { Msgpax , :unpack! , [ [ binary : true ] ] } # ... rest of the pipeline end","ref":"Msgpax.PlugParser.html","title":"Msgpax.PlugParser","type":"module"},{"doc":"Callback implementation for Plug.Parsers.init/1 .","ref":"Msgpax.PlugParser.html#init/1","title":"Msgpax.PlugParser.init/1","type":"function"},{"doc":"Callback implementation for Plug.Parsers.parse/5 .","ref":"Msgpax.PlugParser.html#parse/5","title":"Msgpax.PlugParser.parse/5","type":"function"},{"doc":"Reserved extensions automatically get handled by Msgpax.","ref":"Msgpax.ReservedExt.html","title":"Msgpax.ReservedExt","type":"module"},{"doc":"","ref":"Msgpax.ReservedExt.html#t:t/0","title":"Msgpax.ReservedExt.t/0","type":"opaque"},{"doc":"Exception that represents an error in packing terms. This exception has a :reason field that can have one of the following values: {:not_encodable, term} - means that the given argument is not serializable. For example, this is returned when you try to pack bits instead of a binary (as only binaries can be serialized). {:too_big, term} - means that the given term is too big to be encoded. What &quot;too big&quot; means depends on the term being encoded; for example, integers larger than 18_446_744_073_709_551_616 are too big to be encoded with MessagePack.","ref":"Msgpax.PackError.html","title":"Msgpax.PackError","type":"exception"},{"doc":"Callback implementation for Exception.message/1 .","ref":"Msgpax.PackError.html#message/1","title":"Msgpax.PackError.message/1","type":"function"},{"doc":"","ref":"Msgpax.PackError.html#t:t/0","title":"Msgpax.PackError.t/0","type":"type"},{"doc":"Raised when there's an error in deserializing some data into an Elixir term.","ref":"Msgpax.UnpackError.html","title":"Msgpax.UnpackError","type":"exception"},{"doc":"Callback implementation for Exception.message/1 .","ref":"Msgpax.UnpackError.html#message/1","title":"Msgpax.UnpackError.message/1","type":"function"},{"doc":"","ref":"Msgpax.UnpackError.html#t:t/0","title":"Msgpax.UnpackError.t/0","type":"type"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Dropped support for Elixir versions before 1.6. Fixed a deprecation warning from Bitwise .","ref":"changelog.html#v2-4-0-2023-05-27","title":"Changelog - v2.4.0 – 2023-05-27","type":"extras"},{"doc":"Added support for iolists in Msgpax.Ext . Fixed iolist Msgpax.Fragment inspecting.","ref":"changelog.html#v2-3-1-2022-11-16","title":"Changelog - v2.3.1 – 2022-11-16","type":"extras"},{"doc":"Introduced support for MessagePack data fragment manipulation. Optimized unpacking even more for typical usage scenarios. Fixed error raising in Msgpax.pack/1 when protocol Msgpax.Packer is not implemented for the given data types. Complete IEEE 754 support: added NaN and ±infinity.","ref":"changelog.html#v2-3-0-2021-02-05","title":"Changelog - v2.3.0 – 2021-02-05","type":"extras"},{"doc":"Optimized list and map packing.","ref":"changelog.html#v2-2-4-2019-07-23","title":"Changelog - v2.2.4 – 2019-07-23","type":"extras"},{"doc":"Optimized packing by generating less garbage.","ref":"changelog.html#v2-2-3-2019-05-13","title":"Changelog - v2.2.3 – 2019-05-13","type":"extras"},{"doc":"Fixed bare struct unpacking in Msgpax.PlugParser —the same behaviour when unpacking maps.","ref":"changelog.html#v2-2-2-2019-02-25","title":"Changelog - v2.2.2 – 2019-02-25","type":"extras"},{"doc":"Fixed deprecation warnings for using non-empty lists with the Collectable protocol.","ref":"changelog.html#v2-2-1-2019-01-29","title":"Changelog - v2.2.1 – 2019-01-29","type":"extras"},{"doc":"Added the :unpacker option support in Msgpax.PlugParser .","ref":"changelog.html#v2-2-0-2019-01-16","title":"Changelog - v2.2.0 – 2019-01-16","type":"extras"},{"doc":"Made unpacking even slightly more optimized.","ref":"changelog.html#v2-1-1-2018-02-02","title":"Changelog - v2.1.1 – 2018-02-02","type":"extras"},{"doc":"Added support for the Timestamp extension type. Improved handling of reserved extension types—unpacking will not fail for reserved extension types added in future.","ref":"changelog.html#v2-1-0-2017-12-08","title":"Changelog - v2.1.0 – 2017-12-08","type":"extras"},{"doc":"Optimized unpacking by using single match context. Optimized packing by producing smaller iodata. Breaking changes: Dropped support for Elixir versions before 1.4. Converted all error reasons to proper exceptions: non-raising functions now return {:error, Msgpax.PackError.t | Msgpax.UnpackError.t} in case of failure instead of {:error, term} . Stopped packing keyword lists as maps and started raising an exception when trying to pack a keyword list: from now on explicit conversion from keyword lists to maps is required, or alternatively the Msgpax.Packer protocol must be implemented for tuples.","ref":"changelog.html#v2-0-0-2017-05-23","title":"Changelog - v2.0.0 – 2017-05-23","type":"extras"},{"doc":"Added the :include_struct_field option for Msgpax.Packer protocol deriving.","ref":"changelog.html#v1-1-0-2017-01-23","title":"Changelog - v1.1.0 – 2017-01-23","type":"extras"},{"doc":"Added the :iodata option to Msgpax.pack/2 and Msgpax.pack!/2 . Added the Msgpax.Ext.Unpacker behaviour. Added the Msgpax.PlugParser module which implements the Plug.Parsers behaviour. Added the :fields option for @derive . Breaking changes: Renamed Msgpax.Packer.transform/1 to Msgpax.Packer.pack/1 , so all protocol implementations should be updated.","ref":"changelog.html#v1-0-0-2016-08-23","title":"Changelog - v1.0.0 – 2016-08-23","type":"extras"}]